@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..9\n"; }
+BEGIN { $| = 1; print "1..14\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use HTML::Template;
 $loaded = 1;
@@ -20,8 +20,10 @@ print "ok 1\n";
 
 # test a simple template
 my $template = HTML::Template->new(
-                                       filename => 'templates/simple.tmpl',                                
-                                      );
+                                   filename => 'templates/simple.tmpl',
+                                   debug => 0
+                                  );
+
 $template->param('ADJECTIVE', 'very');
 my $output =  $template->output;
 if ($output =~ /ADJECTIVE/) {
@@ -29,7 +31,7 @@ if ($output =~ /ADJECTIVE/) {
 } elsif ($output =~ /very/) {
   print "ok 2\n";
 } else {
-  die "not ok 2\n";
+  die "not ok 2 : $output\n";
 }
 
 # try something a bit larger
@@ -69,16 +71,17 @@ if ($output =~ /<TMPL_VAR/) {
 # test a simple loop template
 my $template = HTML::Template->new(
                                    filename => 'templates/simple-loop.tmpl',
+                                   # debug => 1
                                   );
 $template->param('ADJECTIVE_LOOP', [ { ADJECTIVE => 'really' }, { ADJECTIVE => 'very' } ] );
 
 my $output =  $template->output;
 if ($output =~ /ADJECTIVE_LOOP/) {
-  die "not ok 4\n\n";
+  die "not ok 4\n$output";
 } elsif ($output =~ /really.*very/s) {
   print "ok 4\n";
 } else {
-  die "not ok 4\n\n";
+  die "not ok 4\n$output";
 }
 
 # test a simple loop template
@@ -160,4 +163,77 @@ if ($output =~ /ADJECTIVE/) {
   die "not ok 9\n";
 }
 
+# test a simple loop template
+my $template_l = HTML::Template->new(
+                                   filename => 'templates/other-loop.tmpl',
+                                     # debug => 1
+                                  );
+# $template_l->param('ADJECTIVE_LOOP', [ { ADJECTIVE => 'really' }, { ADJECTIVE => 'very' } ] );
 
+my $output =  $template_l->output;
+if ($output =~ /INSIDE/) {
+  die "not ok 10\n";
+} else {
+  print "ok 10\n";
+}
+
+
+# test a simple if template
+my $template_i = HTML::Template->new(
+                                   filename => 'templates/if.tmpl',
+                                     # debug => 1
+                                  );
+# $template_l->param('ADJECTIVE_LOOP', [ { ADJECTIVE => 'really' }, { ADJECTIVE => 'very' } ] );
+
+my $output =  $template_i->output;
+if ($output =~ /INSIDE/) {
+  die "not ok 11\n";
+} else {
+  print "ok 11\n";
+}
+
+# test a simple if template
+my $template_i2 = HTML::Template->new(
+                                   filename => 'templates/if.tmpl',
+                                     # debug => 1
+                                  );
+$template_i2->param(BOOL => 1);
+
+my $output =  $template_i2->output;
+if ($output !~ /INSIDE/) {
+  die "not ok 12\n";
+} else {
+  print "ok 12\n";
+}
+
+
+# test a simple if/else template
+my $template_ie = HTML::Template->new(
+                                   filename => 'templates/ifelse.tmpl',
+                                     # debug => 1
+                                  );
+
+my $output =  $template_ie->output;
+if ($output !~ /INSIDE ELSE/) {
+  die "not ok 13\n";
+} elsif ($output =~ /INSIDE IF/) {
+  die "not ok 13\n";
+} else {
+  print "ok 13\n";
+}
+
+# test a simple if/else template
+my $template_ie2 = HTML::Template->new(
+                                   filename => 'templates/ifelse.tmpl',
+                                     # debug => 1
+                                  );
+$template_ie2->param(BOOL => 1);
+
+my $output =  $template_ie2->output;
+if ($output !~ /INSIDE IF/) {
+  die "not ok 14\n";
+} elsif ($output =~ /INSIDE ELSE/) {
+  die "not ok 14\n";
+} else {
+  print "ok 14\n";
+}
